@@ -157,6 +157,8 @@ class CogniflyController:
             self.udp_int = UDPInterface()
             self.drone_hostname = socket.gethostname() if drone_hostname is None else drone_hostname
             self.drone_ip = socket.gethostbyname(self.drone_hostname) if drone_hostname is not None else extract_ip()
+            if drone_hostname is None and (self.drone_ip == '127.0.0.1' or self.drone_ip == '0.0.0.0'):
+                raise RuntimeError(f"Could not extract drone IP ({self.drone_ip})")
             self.drone_port = drone_port
             self.udp_int.init_receiver(ip=self.drone_ip, port=self.drone_port)
             self.tcp_video_int = TCPVideoInterface()
@@ -256,25 +258,28 @@ class CogniflyController:
     def run_curses(self):
         result = 1
         try:
-            # get the curses screen window
-            screen = curses.initscr()
-            # turn off input echoing
-            curses.noecho()
-            # respond to keys immediately (don't wait for enter)
-            curses.cbreak()
-            # non-blocking
-            screen.timeout(0)
-            # map arrow keys to special values
-            screen.keypad(True)
             if self.print_screen:
+                # get the curses screen window
+                screen = curses.initscr()
+                # turn off input echoing
+                curses.noecho()
+                # respond to keys immediately (don't wait for enter)
+                curses.cbreak()
+                # non-blocking
+                screen.timeout(0)
+                # map arrow keys to special values
+                screen.keypad(True)
                 screen.addstr(1, 0, "Press 'q' to quit, 'r' to reboot, 'm' to change mode, 'a' to arm, 'd' to disarm and arrow keys to control", curses.A_BOLD)
+            else:
+                screen = None
             result = self._controller(screen)
         finally:
             # shut down cleanly
-            curses.nocbreak()
-            screen.keypad(0)
-            curses.echo()
-            curses.endwin()
+            if self.print_screen:
+                curses.nocbreak()
+                screen.keypad(0)
+                curses.echo()
+                curses.endwin()
             if result == 1:
                 print("An error occurred, probably the serial port is not available")
 
@@ -723,103 +728,104 @@ class CogniflyController:
                     # end of UDP recv non-blocking -----------------------------
                     #
 
-                    char = screen.getch()  # get keypress
-                    curses.flushinp()  # flushes buffer
-                    #
-                    # KEYS (NO DELAYS) -----------------------------------------
-                    #
-                    if char != -1:
-                        self.key_cmd_in_progress = True
-                        self.last_key_tick = time.time()
+                    if self.print_screen:
+                        char = screen.getch()  # get keypress
+                        curses.flushinp()  # flushes buffer
+                        #
+                        # KEYS (NO DELAYS) -----------------------------------------
+                        #
+                        if char != -1:
+                            self.key_cmd_in_progress = True
+                            self.last_key_tick = time.time()
 
-                        if char == QUIT_CHR:
-                            break
+                            if char == QUIT_CHR:
+                                break
 
-                        elif char == DISARM_CHR:
-                            cursor_msg = 'Disarming...'
-                            self.CMDS['aux1'] = 1000
+                            elif char == DISARM_CHR:
+                                cursor_msg = 'Disarming...'
+                                self.CMDS['aux1'] = 1000
 
-                        elif char == REBOOT_CHR:
-                            if self.print_screen:
-                                screen.addstr(3, 0, 'Rebooting...')
-                                screen.clrtoeol()
-                            board.reboot()
-                            time.sleep(0.5)
-                            break
+                            elif char == REBOOT_CHR:
+                                if self.print_screen:
+                                    screen.addstr(3, 0, 'Rebooting...')
+                                    screen.clrtoeol()
+                                board.reboot()
+                                time.sleep(0.5)
+                                break
 
-                        elif char == ARM_CHR:
-                            cursor_msg = 'Arming...'
-                            self.CMDS['aux1'] = 1800
+                            elif char == ARM_CHR:
+                                cursor_msg = 'Arming...'
+                                self.CMDS['aux1'] = 1800
 
-                        elif char == SWITCH_MODE_CHR:
-                            if self.CMDS['aux2'] <= 1300:
-                                cursor_msg = 'NAV ALTHOLD Mode...'
-                                self.CMDS['aux2'] = 1500
-                            elif 1700 > self.CMDS['aux2'] > 1300:
-                                cursor_msg = 'NAV POSHOLD Mode...'
-                                self.CMDS['aux2'] = 1800
-                            elif self.CMDS['aux2'] >= 1650:
-                                cursor_msg = 'Angle Mode...'
-                                self.CMDS['aux2'] = 1000
+                            elif char == SWITCH_MODE_CHR:
+                                if self.CMDS['aux2'] <= 1300:
+                                    cursor_msg = 'NAV ALTHOLD Mode...'
+                                    self.CMDS['aux2'] = 1500
+                                elif 1700 > self.CMDS['aux2'] > 1300:
+                                    cursor_msg = 'NAV POSHOLD Mode...'
+                                    self.CMDS['aux2'] = 1800
+                                elif self.CMDS['aux2'] >= 1650:
+                                    cursor_msg = 'Angle Mode...'
+                                    self.CMDS['aux2'] = 1000
 
-                        elif char == RIGHT_CHR:
-                            # self.CMDS['roll'] = self.CMDS['roll'] + 10 if self.CMDS['roll'] + 10 <= 2000 else self.CMDS['roll']
-                            self.CMDS['roll'] = KEY_P_ROLL
-                            cursor_msg = 'roll(+):{}'.format(self.CMDS['roll'])
+                            elif char == RIGHT_CHR:
+                                # self.CMDS['roll'] = self.CMDS['roll'] + 10 if self.CMDS['roll'] + 10 <= 2000 else self.CMDS['roll']
+                                self.CMDS['roll'] = KEY_P_ROLL
+                                cursor_msg = 'roll(+):{}'.format(self.CMDS['roll'])
 
-                        elif char == LEFT_CHR:
-                            # self.CMDS['roll'] = self.CMDS['roll'] - 10 if self.CMDS['roll'] - 10 >= 1000 else self.CMDS['roll']
-                            self.CMDS['roll'] = KEY_N_ROLL
-                            cursor_msg = 'roll(-):{}'.format(self.CMDS['roll'])
+                            elif char == LEFT_CHR:
+                                # self.CMDS['roll'] = self.CMDS['roll'] - 10 if self.CMDS['roll'] - 10 >= 1000 else self.CMDS['roll']
+                                self.CMDS['roll'] = KEY_N_ROLL
+                                cursor_msg = 'roll(-):{}'.format(self.CMDS['roll'])
 
-                        elif char == RIGHTYAW_CHR:
-                            self.CMDS['yaw'] = KEY_P_YAW
-                            cursor_msg = 'yaw(+):{}'.format(self.CMDS['yaw'])
+                            elif char == RIGHTYAW_CHR:
+                                self.CMDS['yaw'] = KEY_P_YAW
+                                cursor_msg = 'yaw(+):{}'.format(self.CMDS['yaw'])
 
-                        elif char == LEFTYAW_CHR:
-                            self.CMDS['yaw'] = KEY_N_YAW
-                            cursor_msg = 'yaw(-):{}'.format(self.CMDS['yaw'])
+                            elif char == LEFTYAW_CHR:
+                                self.CMDS['yaw'] = KEY_N_YAW
+                                cursor_msg = 'yaw(-):{}'.format(self.CMDS['yaw'])
 
-                        elif char == FORWARD_CHR:
-                            # self.CMDS['pitch'] = self.CMDS['pitch'] + 10 if self.CMDS['pitch'] + 10 <= 2000 else self.CMDS['pitch']
-                            self.CMDS['pitch'] = KEY_P_PITCH
-                            cursor_msg = 'pitch(+):{}'.format(self.CMDS['pitch'])
+                            elif char == FORWARD_CHR:
+                                # self.CMDS['pitch'] = self.CMDS['pitch'] + 10 if self.CMDS['pitch'] + 10 <= 2000 else self.CMDS['pitch']
+                                self.CMDS['pitch'] = KEY_P_PITCH
+                                cursor_msg = 'pitch(+):{}'.format(self.CMDS['pitch'])
 
-                        elif char == BACKWARD_CHR:
-                            # self.CMDS['pitch'] = self.CMDS['pitch'] - 10 if self.CMDS['pitch'] - 10 >= 1000 else self.CMDS['pitch']
-                            self.CMDS['pitch'] = KEY_N_PITCH
-                            cursor_msg = 'pitch(-):{}'.format(self.CMDS['pitch'])
+                            elif char == BACKWARD_CHR:
+                                # self.CMDS['pitch'] = self.CMDS['pitch'] - 10 if self.CMDS['pitch'] - 10 >= 1000 else self.CMDS['pitch']
+                                self.CMDS['pitch'] = KEY_N_PITCH
+                                cursor_msg = 'pitch(-):{}'.format(self.CMDS['pitch'])
 
-                        elif char == UPWARD_CHR:
-                            self.CMDS['throttle'] = self.CMDS['throttle'] + KEY_P_THROTTLE if self.CMDS['throttle'] + KEY_P_THROTTLE <= MAX_CMD_THROTTLE else self.CMDS['throttle']
-                            cursor_msg = 'throttle(+):{}'.format(self.CMDS['throttle'])
+                            elif char == UPWARD_CHR:
+                                self.CMDS['throttle'] = self.CMDS['throttle'] + KEY_P_THROTTLE if self.CMDS['throttle'] + KEY_P_THROTTLE <= MAX_CMD_THROTTLE else self.CMDS['throttle']
+                                cursor_msg = 'throttle(+):{}'.format(self.CMDS['throttle'])
 
-                        elif char == DOWNWARD_CHR:
-                            self.CMDS['throttle'] = self.CMDS['throttle'] + KEY_N_THROTTLE if self.CMDS['throttle'] + KEY_N_THROTTLE >= MIN_CMD_THROTTLE else self.CMDS['throttle']
-                            cursor_msg = 'throttle(-):{}'.format(self.CMDS['throttle'])
+                            elif char == DOWNWARD_CHR:
+                                self.CMDS['throttle'] = self.CMDS['throttle'] + KEY_N_THROTTLE if self.CMDS['throttle'] + KEY_N_THROTTLE >= MIN_CMD_THROTTLE else self.CMDS['throttle']
+                                cursor_msg = 'throttle(-):{}'.format(self.CMDS['throttle'])
 
-                        elif char == TAKEOFF_CHR:
-                            self.CMDS['throttle'] = KEY_TAKEOFF
-                            cursor_msg = 'takeoff throttle:{}'.format(self.CMDS['throttle'])
+                            elif char == TAKEOFF_CHR:
+                                self.CMDS['throttle'] = KEY_TAKEOFF
+                                cursor_msg = 'takeoff throttle:{}'.format(self.CMDS['throttle'])
 
-                        elif char == LAND_CHR:
-                            self.CMDS['throttle'] = KEY_LAND
-                            cursor_msg = 'land throttle:{}'.format(self.CMDS['throttle'])
+                            elif char == LAND_CHR:
+                                self.CMDS['throttle'] = KEY_LAND
+                                cursor_msg = 'land throttle:{}'.format(self.CMDS['throttle'])
 
-                        elif PAUSE_CHR:
-                            self.CMDS['roll'] = DEFAULT_ROLL
-                            self.CMDS['pitch'] = DEFAULT_PITCH
-                            self.CMDS['yaw'] = DEFAULT_YAW
+                            elif PAUSE_CHR:
+                                self.CMDS['roll'] = DEFAULT_ROLL
+                                self.CMDS['pitch'] = DEFAULT_PITCH
+                                self.CMDS['yaw'] = DEFAULT_YAW
 
-                    elif self.key_cmd_in_progress:  # default behavior
-                        if time.time() - self.last_key_tick >= KEY_TIMEOUT:
-                            self.key_cmd_in_progress = False
-                            self.CMDS['roll'] = DEFAULT_ROLL
-                            self.CMDS['pitch'] = DEFAULT_PITCH
-                            self.CMDS['yaw'] = DEFAULT_YAW
-                    #
-                    # End of KEYS ----------------------------------------------
-                    #
+                        elif self.key_cmd_in_progress:  # default behavior
+                            if time.time() - self.last_key_tick >= KEY_TIMEOUT:
+                                self.key_cmd_in_progress = False
+                                self.CMDS['roll'] = DEFAULT_ROLL
+                                self.CMDS['pitch'] = DEFAULT_PITCH
+                                self.CMDS['yaw'] = DEFAULT_YAW
+                        #
+                        # End of KEYS ----------------------------------------------
+                        #
 
                     #
                     # CLIP RC VALUES -------------------------------------------
@@ -937,8 +943,8 @@ class CogniflyController:
             print("Bye!")
 
 
-def run_controller():
-    cc = CogniflyController()
+def run_controller(print_screen=True):
+    cc = CogniflyController(print_screen=print_screen)
     cc.run_curses()
 
 
